@@ -28,6 +28,15 @@ for arg in $*; do
     esac
 done
 
+# Workaround for gtk-doc + shave + libtool 1.x
+# See http://git.lespiau.name/cgit/shave/tree/README#n83
+sed -e 's#) --mode=compile#) --tag=CC --mode=compile#' gtk-doc.make \
+    > gtk-doc.temp \
+    && mv gtk-doc.temp gtk-doc.make
+sed -e 's#) --mode=link#) --tag=CC --mode=link#' gtk-doc.make \
+    > gtk-doc.temp \
+        && mv gtk-doc.temp gtk-doc.make
+
 if test $run_configure = true; then
     ./configure "$@"
 fi
