@@ -38,8 +38,6 @@ struct _TpConnectionPrivate {
     TpConnectionStatusReason status_reason;
     GError *connection_error /* initialized statically */;
 
-    TpConnectionAliasFlags alias_flags;
-
     /* GArray of GQuark */
     GArray *contact_attribute_interfaces;
 
@@ -47,6 +45,7 @@ struct _TpConnectionPrivate {
     GHashTable *contacts;
 
     unsigned ready:1;
+    unsigned called_get_interfaces:1;
     unsigned tracking_aliases_changed:1;
     unsigned tracking_avatar_updated:1;
     unsigned tracking_presences_changed:1;
